@@ -19,7 +19,7 @@ def simulate_tabplot_binning(df, nbins=100, sort_col=None, decreasing=True, max_
     """
     Simulates the binning and aggregation process of R's tabplot.
     This function is an INTERPRETATION, not a direct line-by-line translation,
-    due to the complexity and dependencies of R packages (`ff`, `ffbase`, `grid`).
+    due to the complexity and dependencies of R packages (ff, ffbase, grid).
     
     Arguments:
         df (pd.DataFrame): Input DataFrame.
@@ -525,5 +525,3 @@ def tableplot(df, cols, sort_col, ascending=False, nbins=100, max_levels=50, tit
 
 
 
-
-
